@@ -294,7 +294,7 @@
  * Character sets
  */
 #define MYSQL_DEFAULT_CHARSET_NAME "utf8mb4"
-#define MYSQL_DEFAULT_COLLATION_NAME "utf8mb4_unicode_ci"
+#define MYSQL_DEFAULT_COLLATION_NAME "utf8mb4_general_ci"
 /* #undef HAVE_CHARSET_armscii8 */
 /* #undef HAVE_CHARSET_ascii */
 #define HAVE_CHARSET_big5 1
